@@ -221,12 +221,12 @@ int mbedtls_base64_decode(unsigned char *dst, size_t dlen, size_t *olen,
 
 // secretbase - internals ------------------------------------------------------
 
-static SEXP sb_raw_char(const unsigned char *buf, const size_t sz) {
+SEXP sb_raw_char(unsigned char *buf, const size_t sz) {
 
   int i;
   for (i = 0; i < sz; i++) if (!buf[i]) break;
   if (sz - i > 1) {
-    R_Free(buf);
+    free(buf);
     Rf_error("data could not be converted to a character string");
   }
   
@@ -259,7 +259,12 @@ static inline void sb_write_bytes(R_outpstream_t stream, void *src, int len) {
     do {
       buf->len += buf->len > SB_SERIAL_THR ? SB_SERIAL_THR : buf->len;
     } while (buf->len < req);
-    buf->buf = R_Realloc(buf->buf, buf->len, unsigned char);
+    unsigned char *tmp = realloc(buf->buf, buf->len);
+    if (tmp == NULL) {
+      free(buf->buf);
+      Rf_error("memory allocation failed");
+    }
+    buf->buf = tmp;
   }
   
   memcpy(buf->buf + buf->cur, src, len);
@@ -288,7 +293,7 @@ static void sb_serialize(nano_buf *buf, const SEXP object) {
   
 }
 
-static SEXP sb_unserialize(unsigned char *buf, const size_t sz) {
+SEXP sb_unserialize(unsigned char *buf, const size_t sz) {
 
   nano_buf nbuf;
   struct R_inpstream_st input_stream;
@@ -311,20 +316,20 @@ static SEXP sb_unserialize(unsigned char *buf, const size_t sz) {
   
 }
 
-static nano_buf sb_any_buf(const SEXP x) {
+nano_buf sb_any_buf(const SEXP x) {
   
   nano_buf buf;
   
   switch (TYPEOF(x)) {
   case STRSXP:
-    if (XLENGTH(x) == 1 && !ANY_ATTRIB(x)) {
+    if (XLENGTH(x) == 1 && NO_ATTRIB(x)) {
       const char *s = CHAR(*STRING_PTR_RO(x));
       NANO_INIT(&buf, (unsigned char *) s, strlen(s));
       break;
     }
   if (0) {
   case RAWSXP:
-    if (!ANY_ATTRIB(x)) {
+    if (NO_ATTRIB(x)) {
       NANO_INIT(&buf, (unsigned char *) DATAPTR_RO(x), XLENGTH(x));
       break;
     }
@@ -349,19 +354,23 @@ SEXP secretbase_base64enc(SEXP x, SEXP convert) {
   
   nano_buf hash = sb_any_buf(x);
   xc = mbedtls_base64_encode(NULL, 0, &olen, hash.buf, hash.cur);
-  unsigned char *buf = R_Calloc(olen, unsigned char);
+  unsigned char *buf = malloc(olen);
+  if (buf == NULL) {
+    NANO_FREE(hash);
+    Rf_error("memory allocation failed");
+  }
   xc = mbedtls_base64_encode(buf, olen, &olen, hash.buf, hash.cur);
   NANO_FREE(hash);
   CHECK_ERROR(xc, buf);
-  
+
   if (conv) {
     out = sb_raw_char(buf, olen);
   } else {
     out = Rf_allocVector(RAWSXP, olen);
     memcpy(SB_DATAPTR(out), buf, olen);
   }
-  
-  R_Free(buf);
+
+  free(buf);
   
   return out;
   
@@ -372,18 +381,19 @@ SEXP secretbase_base64dec(SEXP x, SEXP convert) {
   SB_ASSERT_LOGICAL(convert);
   const int conv = SB_LOGICAL(convert);
   int xc;
-  unsigned char *inbuf;
+  const unsigned char *inbuf;
   SEXP out;
   size_t inlen, olen;
   
   switch (TYPEOF(x)) {
-  case STRSXP: ;
+  case STRSXP: {
     const char *str = CHAR(*STRING_PTR_RO(x));
     inbuf = (unsigned char *) str;
     inlen = strlen(str);
     break;
+  }
   case RAWSXP:
-    inbuf = RAW(x);
+    inbuf = (unsigned char *) DATAPTR_RO(x);
     inlen = XLENGTH(x);
     break;
   default:
@@ -393,10 +403,12 @@ SEXP secretbase_base64dec(SEXP x, SEXP convert) {
   xc = mbedtls_base64_decode(NULL, 0, &olen, inbuf, inlen);
   if (xc == MBEDTLS_ERR_BASE64_INVALID_CHARACTER)
     Rf_error("input is not valid base64");
-  unsigned char *buf = R_Calloc(olen, unsigned char);
+  unsigned char *buf = malloc(olen);
+  if (buf == NULL)
+    Rf_error("memory allocation failed");
   xc = mbedtls_base64_decode(buf, olen, &olen, inbuf, inlen);
   CHECK_ERROR(xc, buf);
-  
+
   switch (conv) {
   case 0:
     out = Rf_allocVector(RAWSXP, olen);
@@ -408,8 +420,8 @@ SEXP secretbase_base64dec(SEXP x, SEXP convert) {
   default:
     out = sb_unserialize(buf, olen);
   }
-  
-  R_Free(buf);
+
+  free(buf);
   
   return out;
   
